@@ -1,11 +1,15 @@
 import React, {PropTypes} from 'react';
+import FormLabel from '../../components/style/form-label'
+import FormColorInput from '../../components/style/form-color-input';
 
 export default function PropertyColor({propertyName, value, onUpdate, configs}) {
   return (
     <div style={{marginBottom: "3px"}}>
-      <label style={{width: "30%", display: "inline-block"}}>{propertyName}</label>
+      <div style={{display: "inline-block", width: "30%"}}>
+        <FormLabel>{propertyName}</FormLabel>
+      </div>
       <div style={{display: "inline-block", width: "70%"}}>
-        <input type="color" value={value} onChange={event => onUpdate(event.target.value)}/>
+        <FormColorInput value={value} onChange={event => onUpdate(event.target.value)}/>
       </div>
     </div>
   );
