@@ -11,6 +11,8 @@ export const SET_PROPERTIES = 'SET_PROPERTIES';
 export const REMOVE = 'REMOVE';
 export const UNDO = 'UNDO';
 export const ROLLBACK = 'ROLLBACK';
+export const SET_PROJECT_PROPERTIES = 'SET_PROJECT_PROPERTIES';
+export const OPEN_PROJECT_CONFIGURATOR = 'OPEN_PROJECT_CONFIGURATOR';
 
 // ACTIONS viewer2D
 export const SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -66,6 +68,8 @@ export const END_DRAGGING_VERTEX = 'END_DRAGGING_VERTEX';
 export const SET_LAYER_PROPERTIES = 'SET_LAYER_PROPERTIES';
 export const ADD_LAYER = 'ADD_LAYER';
 export const SELECT_LAYER = 'SELECT_LAYER';
+export const OPEN_LAYER_CONFIGURATOR = 'OPEN_LAYER_CONFIGURATOR';
+export const REMOVE_LAYER = 'REMOVE_LAYER';
 
 //MODES
 export const MODE_IDLE = 'IDLE';
@@ -86,7 +90,8 @@ export const MODE_ROTATING_ITEM = 'MODE_ROTATING_ITEM';
 export const MODE_UPLOADING_IMAGE = 'MODE_UPLOADING_IMAGE';
 export const MODE_FITTING_IMAGE = 'MODE_FITTING_IMAGE';
 export const MODE_VIEWING_CATALOG = 'MODE_VIEWING_CATALOG';
-
+export const MODE_CONFIGURING_PROJECT = 'MODE_CONFIGURING_PROJECT';
+export const MODE_CONFIGURING_LAYER = 'MODE_CONFIGURING_LAYER';
 
 
 //unit
